==> core-react-0.8.0.tgz: package/es/Nav/NavItem.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../Icon';

var NavItem = /*#__PURE__*/function (_React$Component) {
  _inherits(NavItem, _React$Component);

  function NavItem(props) {
    var _this;

    _classCallCheck(this, NavItem);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(NavItem).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (e) {
      _this.props.onClick && _this.props.onClick(e);

      _this.context.nav.handleItemClick(_this.props, e);
    });

    _this.state = {
      active: false
    };
    return _this;
  }

  _createClass(NavItem, [{
    key: "setActiveState",
    value: function setActiveState(props) {
      var active = this.context.nav.state.selectedId === props.id;
      this.setState({
        active: active
      });
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.setActiveState(this.props);
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      this.setActiveState(nextProps);
    }
  }, {
    key: "render",
    value: function render() {
      var active = this.state.active;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          icon = _this$props.icon,
          title = _this$props.title,
          other = _objectWithoutProperties(_this$props, ["children", "className", "icon", "title"]);

      var NavItemIcon = /\//.test(icon) ? React.createElement(Icon, {
        className: "".concat("waui", "-nav__item-icon"),
        src: icon
      }) : React.createElement(Icon, {
        type: icon,
        className: "".concat("waui", "-nav__item-icon")
      });
      return React.createElement("li", _extends({
        onClick: this.handleClick,
        className: cx("".concat("waui", "-nav__item"), _defineProperty({}, "".concat("waui", "-nav__item--active"), active), className)
      }, other), React.createElement("div", {
        className: "".concat("waui", "-nav__item-title")
      }, NavItemIcon, React.createElement("span", null, title, children)));
    }
  }]);

  return NavItem;
}(React.Component);

NavItem.contextTypes = {
  nav: PropTypes.object
};
NavItem.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** The id of navigation item */
  id: PropTypes.string.isRequired,

  /** Navigation item title which can be a text string or a React element */
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /** Click the navigation item will call this function */
  onClick: PropTypes.func,

  /** Navigation item icon, support `Icon` component or svg url. It's not recommended. */
  icon: PropTypes.string
};
export default NavItem;

==> core-react-0.8.2.tgz: package/es/Nav/NavItem.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../Icon';

var NavItem = /*#__PURE__*/function (_React$Component) {
  _inherits(NavItem, _React$Component);

  function NavItem(props) {
    var _this;

    _classCallCheck(this, NavItem);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(NavItem).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (e) {
      _this.props.onClick && _this.props.onClick(e);

      _this.context.nav.handleItemClick(_this.props, e);
    });

    _this.state = {
      active: false
    };
    return _this;
  }

  _createClass(NavItem, [{
    key: "setActiveState",
    value: function setActiveState(props) {
      var active = this.context.nav.state.selectedId === props.id;
      this.setState({
        active: active
      });
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.setActiveState(this.props);
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      this.setActiveState(nextProps);
    }
  }, {
    key: "render",
    value: function render() {
      var active = this.state.active;

      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          icon = _this$props.icon,
          title = _this$props.title,
          other = _objectWithoutProperties(_this$props, ["children", "className", "icon", "title"]);

      var NavItemIcon = /\//.test(icon) ? /*#__PURE__*/React.createElement(Icon, {
        className: "".concat("waui", "-nav__item-icon"),
        src: icon
      }) : /*#__PURE__*/React.createElement(Icon, {
        type: icon,
        className: "".concat("waui", "-nav__item-icon")
      });
      return (/*#__PURE__*/React.createElement("li", _extends({
          onClick: this.handleClick,
          className: cx("".concat("waui", "-nav__item"), _defineProperty({}, "".concat("waui", "-nav__item--active"), active), className)
        }, other), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-nav__item-title")
        }, NavItemIcon, /*#__PURE__*/React.createElement("span", null, title, children)))
      );
    }
  }]);

  return NavItem;
}(React.Component);

NavItem.contextTypes = {
  nav: PropTypes.object
};
NavItem.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** The id of navigation item */
  id: PropTypes.string.isRequired,

  /** Navigation item title which can be a text string or a React element */
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /** Click the navigation item will call this function */
  onClick: PropTypes.func,

  /** Navigation item icon, support `Icon` component or svg url. It's not recommended. */
  icon: PropTypes.string
};
export default NavItem;
